//=============================================================================
// (c) Copyright 2014 Diamond Systems Corporation. Use of this source code
// is subject to the terms of Diamond Systems' Software License Agreement.
// Diamond Systems provides no warranty of proper performance if this
// source code is modified.
//
// File: MPEDAQ0804PWMFunction.c  v7.00
//
// Depedency :	Universal Driver version 7.00
//				DSCUD.H - Include file.
//				
//				LIBDSCUD-7.00.a	- Library file for Linux 2.6.29-3.x
//						
//				DSCUD.LIB	- Static library file for Windows 
//						( USE VC++ 6.0 or Visual Studio 2005 )
//				
// Description: This sample code demonstrates the usage of UD function  
//				PWMFunction().  The user selects one of the
//              Pulse Width Modulators (PWM), the output polarity to use,
//              base frequency, and duty cycle of the modulation. 
//============================================================================
#include "DSCUD_demo_def.h"
#include "mpedaq0804.h"


// globals
ERRPARAMS errorParams; // structure for returning error code and error string
// var declarations
DSCB dscb = 0; // handle used to refer to the board
DSCCB dsccb;    // structure containing ISA board settings
DSCCBP dsccbp; // structure containing PCI board settings
BoardInfo *bi=NULL;
char input_buffer[20];
DAQ0804PWM pwm;
//=============================================================================
// Name: main()
// Desc: Starting function that calls the driver functions used
//
//		 NOTE: By convention, you should capture the BYTE return value for each
//		 driver API call, and check the error code.
//
//	     I. Driver Initialization
//	    II. Board Initialization
//	   III. DIO INPUT AND OUTPUT
//	    IV. Cleanup
//
//=============================================================================

int main ( void )
{

	int intBuff = 0; // temp variables of size int
	int temp = 0; // temporary storage
  
   	 BYTE return_value=0;
	int baseadd = 0;
	memset ( &dsccbp, 0, sizeof(DSCCBP) );
	memset ( &pwm, 0 ,sizeof(DAQ0804PWM));

	//=========================================================================
	// I. DRIVER INITIALIZATION
	//
	//    Initializes the DSCUD library.
	//
	//    STEPS TO FOLLOW:
	//
	//	  1. initialize the driver, using the driver version for validation
	//=========================================================================

	if ( (dscInit ( DSC_VERSION ) != DE_NONE) )
	{
		dscGetLastError ( &errorParams );
		printf ( "dscInit error: %s %s\n", dscGetErrorString ( errorParams.ErrCode ), errorParams.errstring );
		return 0;
	}
		
	//=========================================================================
	// II. BOARD INITIALIZATION
	//
	//	   Initialize the MPEDAQ0804 board. This function passes the various
	//	   hardware parameters to the driver and resets the hardware.
	//
	//=========================================================================

	printf ( "\nDSC MPE-DAQ-0804 PWM FUNCTIONS DEMO\n" );

	dsccbp.boardtype = DSC_MPEDAQ0804;
	dsccbp.pci_slot  = 0;
	 
	if(DAQ0804InitBoard ( &dsccbp ) !=DE_NONE)
	{
		dscGetLastError(&errorParams);
		printf("DAQ0804InitBoard error: %s %s\n", dscGetErrorString(errorParams.ErrCode), errorParams.errstring );	
		return 0;
	}
	bi = DSCGetBoardInfo ( dsccbp.boardnum ); 		
   	
	//=========================================================================
	// III. PROGRAM PULSE WIDTH MODULATION
	//
	//	    Program the pulse width modulation. This function takes DAQ0804PWM structure 
	//		as input with PWM no , frequency and duty cycle value.  This function configures the PWM circuit 
	//		and generates PWM signal
	//
	//=========================================================================
	do
	{
		printf("Select PWM no (0-3 ,Default = 0)");
		fgets(input_buffer,20,stdin);
		if(input_buffer[0]=='\n')
		{	
			pwm.Num = 0;
		}
		else
		{
			sscanf(input_buffer,"%d",&pwm.Num);
		}
		
		if(input_buffer[0] == 'q') return 0;
		
		printf("Select Output Frequency (1-50MHz ,Default = 100)");
		fgets(input_buffer,20,stdin);
		if(input_buffer[0]=='\n')
		{	
			pwm.Rate = 100;
		}
		else
		{
			sscanf(input_buffer,"%f",&pwm.Rate);
		}
		
		printf("Select Duty cycle value (1-100,Default = 50)");
		fgets(input_buffer,20,stdin);
		if(input_buffer[0]=='\n')
		{	
			pwm.Duty = 50;
		}
		else
		{
			sscanf(input_buffer,"%f",&pwm.Duty);
		}
		
		printf("Select Polarity (0 = pulse high, 1 = pulse low , Default = 0)");
		fgets(input_buffer,20,stdin);
		if(input_buffer[0]=='\n')
		{	
			pwm.Polarity = 0;
		}
		else
		{
			sscanf(input_buffer,"%d",&pwm.Polarity);
		}
		
		
		pwm.OutputEnable = 1;
		pwm.Run = 0;
		
		if(DAQ0804PWMConfig(bi,&pwm) !=DE_NONE)
		{
			dscGetLastError(&errorParams);
			printf("DAQ0804PWMConfig error: %s %s\n", dscGetErrorString(errorParams.ErrCode), errorParams.errstring );	
			return 0;
		}
		
		printf("Press ENTER key to start PWM \n");
		fgets(input_buffer,20,stdin);
		if( DAQ0804PWMStart(bi,pwm.Num) !=DE_NONE)
		{
			dscGetLastError(&errorParams);
			printf("DAQ0804PWMStart error: %s %s\n", dscGetErrorString(errorParams.ErrCode), errorParams.errstring );	
			return 0;
		}
		
		printf("Press ENTER key to stop PWM \n");
		fgets(input_buffer,20,stdin);
		
		if(DAQ0804PWMStop(bi,pwm.Num) !=DE_NONE)
		{
			dscGetLastError(&errorParams);
			printf("DAQ0804PWMStop error: %s %s\n", dscGetErrorString(errorParams.ErrCode), errorParams.errstring );	
			return 0;
		}
	
		if(DAQ0804PWMReset(bi,pwm.Num) !=DE_NONE)
		{
			dscGetLastError(&errorParams);
			printf("DAQ0804PWMReset error: %s %s\n", dscGetErrorString(errorParams.ErrCode), errorParams.errstring );	
			return 0;
		}
   		printf ("press Enter to repeat or 'q' to quit:");
   		fgets ( input_buffer, 20, stdin );

    } while ( input_buffer[0] != 'q' );
	
	
	
	//=========================================================================
	// IV. CLEANUP
	//
	//	   Cleanup any remnants left by the program and free the resources used
	//	   by the driver.
	//
	//     STEPS TO FOLLOW:
	//
	//	   1. free the driver resources
	//=========================================================================

	dscFree ( );
	
	printf ( "\nDSCPWMFunction completed.\n" );

	return 0;

} // end main()


